==> quarkus-core-deployment-3.4.1-sources.jar: io/quarkus/deployment/dev/testing/TestConfig$Container$$accessor.java <==
package io.quarkus.deployment.dev.testing;
@io.quarkus.Generated("Quarkus annotation processor")
public final class TestConfig$Container$$accessor {
    private TestConfig$Container$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_network(Object __instance) {
        return ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).network;
    }
    @SuppressWarnings("unchecked")
    public static void set_network(Object __instance, Object network) {
        ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).network = (java.util.Optional<String>)network;
    }
    @SuppressWarnings("unchecked")
    public static Object get_additionalExposedPorts(Object __instance) {
        return ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).additionalExposedPorts;
    }
    @SuppressWarnings("unchecked")
    public static void set_additionalExposedPorts(Object __instance, Object additionalExposedPorts) {
        ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).additionalExposedPorts = (java.util.Map<String, String>)additionalExposedPorts;
    }
    @SuppressWarnings("unchecked")
    public static Object get_labels(Object __instance) {
        return ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).labels;
    }
    @SuppressWarnings("unchecked")
    public static void set_labels(Object __instance, Object labels) {
        ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).labels = (java.util.Map<String, String>)labels;
    }
}

==> quarkus-core-deployment-3.6.3-sources.jar: io/quarkus/deployment/dev/testing/TestConfig$Container$$accessor.java <==
package io.quarkus.deployment.dev.testing;
@io.quarkus.Generated("Quarkus annotation processor")
public final class TestConfig$Container$$accessor {
    private TestConfig$Container$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_network(Object __instance) {
        return ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).network;
    }
    @SuppressWarnings("unchecked")
    public static void set_network(Object __instance, Object network) {
        ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).network = (java.util.Optional<String>)network;
    }
    @SuppressWarnings("unchecked")
    public static Object get_additionalExposedPorts(Object __instance) {
        return ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).additionalExposedPorts;
    }
    @SuppressWarnings("unchecked")
    public static void set_additionalExposedPorts(Object __instance, Object additionalExposedPorts) {
        ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).additionalExposedPorts = (java.util.Map<String, String>)additionalExposedPorts;
    }
    @SuppressWarnings("unchecked")
    public static Object get_labels(Object __instance) {
        return ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).labels;
    }
    @SuppressWarnings("unchecked")
    public static void set_labels(Object __instance, Object labels) {
        ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).labels = (java.util.Map<String, String>)labels;
    }
    @SuppressWarnings("unchecked")
    public static Object get_volumeMounts(Object __instance) {
        return ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).volumeMounts;
    }
    @SuppressWarnings("unchecked")
    public static void set_volumeMounts(Object __instance, Object volumeMounts) {
        ((io.quarkus.deployment.dev.testing.TestConfig.Container)__instance).volumeMounts = (java.util.Map<String, String>)volumeMounts;
    }
}
